---
feature_story: FS_88_66_66_73
feature_title: internal `intercept_func`
feature_status: TEST
---


If there is a valid command line:

```sh
some_command           goto service prod downstream wert-pd-1
```

There should be a way to prepend all args by `intercept` and run this command line:

```sh
some_command intercept goto service prod downstream wert-pd-1
```

The purpose of the `intercept` command is to show what plugin and what input it receives on client side.
